% -*- MATLAB -*-
% Time-stamp: "2018-08-15 23:17:55 fujiwara"
%----------------------------------------------------------------------
% Cauchy Problem of the Laplace Equation in 2D
% FDM Computation with 3D plot
%
%  Copyright (C) 2015, FUJIWARA,Hiroshi
%    <fujiwara@acs.i.kyoto-u.ac.jp>
%----------------------------------------------------------------------
clear classes

% Specify locations where *.mexa64 or *.mexmaci64 files exist.
addpath( strcat( pwd, '/exflib' ) );

Nx = 50;  % division number of the interval 0 <= x <= 1.
Ny = 100;  % division number of the interval 0 <= y <= 1.

I = 6*Nx;  % Computation Area
J = Ny/10*4;  % 100 digits
%J = 2*Ny; % 200 digits

%---------------------------------------------
% Enable either one pairs of the followings.
%---------------------------------------------
%one = exfloat(1);  % multiple-precision arithmetic 
one = 1;           % double precision arithmetic

%---------------------------------------------
% Do not edit belows (except Initial Values.) 
%---------------------------------------------
dx = one / Nx;
dy = one / Ny;

for i=1:I+1
  x( i ) = dx * (i-I/2-1);
end
for j=1:J+1
  y( j ) = dy * (j-1);
end

%----------------------------------------
% Initial Value
%----------------------------------------
f = x.*x;
g = 0.*x;
%----------------------------------------
u(1:I+1, 1) = f;
u(1:I+1, 2) = f + dy*g(1:I+1);

lambda = dy*dy/(dx*dx);

%----------------------------------------
% main routine
%----------------------------------------
for j=2:J

  % B.C.
  u(1,j+1) = 0;

  % FDM
  u(2:I,j+1) = 2*u(2:I,j) - u(2:I,j-1)...
      - lambda.*( u(3:I+1,j) - 2*u(2:I,j) + u(1:I-1,j) );

  % B.C.
  u(I+1,j+1) = 0;

end

%----------------------------------------
% output
%----------------------------------------
[yy,xx] = meshgrid( 0:double(dy):double(J*dy), -1:double(dx):1 );
uu = double ( u(2*Nx+1:4*Nx+1, 1:J+1) );
%plot( double(x(2*Nx+1:3*Nx+1:)) ,double(w(2*Ny+1:3*Ny+1)) );
plot3 (yy, xx, uu);

xlabel('y');
ylabel('x');

%----------------------------------------
% end of file
%----------------------------------------
